---
annotations_creators: []
language_creators: []
languages:
- en
licenses: []
multilinguality:
- monolingual
size_categories:
  emergent:
  - 1K<n<10K
  emobank-arousal:
  - 1K<n<10K
  emobank-dominance:
  - 1K<n<10K
  emobank-valence:
  - 1K<n<10K
  gum:
  - 1K<n<10K
  mrda:
  - 10K<n<100K
  pdtb:
  - 10K<n<100K
  persuasiveness-claimtype:
  - n<1K
  persuasiveness-eloquence:
  - n<1K
  persuasiveness-premisetype:
  - n<1K
  persuasiveness-relevance:
  - n<1K
  persuasiveness-specificity:
  - n<1K
  persuasiveness-strength:
  - n<1K
  sarcasm:
  - 1K<n<10K
  squinky-formality:
  - 1K<n<10K
  squinky-implicature:
  - 1K<n<10K
  squinky-informativeness:
  - 1K<n<10K
  stac:
  - 10K<n<100K
  switchboard:
  - 10K<n<100K
  verifiability:
  - 1K<n<10K
source_datasets: []
task_categories:
- text-classification
task_ids:
- multi-class-classification
paperswithcode_id: null
pretty_name: pragmeval
---

### Contributions

Thanks to [@sileod](https://github.com/sileod) for adding this dataset.
